@@ -18,6 +18,10 @@ config = {
         "ACTIVATE_AZURE": True,
         "AZURE_CLIENT_ID": "",
         "AZURE_SECRET_KEY": "",
+
+        "ACTIVATE_GOOGLE": False,
+        "GOOGLE_CLIENT_ID": "",
+        "GOOGLE_SECRET_KEY": "",
     }
 }
 
@@ -40,6 +44,12 @@ def command():
 
 
 def ask_questions_socialoauth(config, defaults):
+    # Azure SSO
+    interactive.ask_bool(
+        "Could you want to enable azure image feature:",
+        "SOCIALOAUTH_ACTIVATE_AZURE", 
+        config, 
+        {"SOCIALOAUTH_ACTIVATE_AZURE": False})
     interactive.ask(
         "Your Azure Client ID:", 
         "SOCIALOAUTH_AZURE_CLIENT_ID",
@@ -50,11 +60,22 @@ def ask_questions_socialoauth(config, defaults):
         "SOCIALOAUTH_AZURE_SECRET_KEY", 
         config, 
         {"SOCIALOAUTH_AZURE_SECRET_KEY": ""})
+    # Google SSO
     interactive.ask_bool(
-        "Could you want to enable azure image feature:",
-        "SOCIALOAUTH_ACTIVATE_AZURE", 
+        "Could you want to enable google image feature:",
+        "SOCIALOAUTH_ACTIVATE_GOOGLE", 
         config, 
-        {"SOCIALOAUTH_ACTIVATE_AZURE": False})
+        {"SOCIALOAUTH_ACTIVATE_GOOGLE": False})
+    interactive.ask(
+        "Your Google Client ID:", 
+        "SOCIALOAUTH_GOOGLE_CLIENT_ID",
+        config, 
+        {"SOCIALOAUTH_GOOGLE_CLIENT_ID": ""})
+    interactive.ask(
+        "Your Google Secret key:", 
+        "SOCIALOAUTH_GOOGLE_SECRET_KEY", 
+        config, 
+        {"SOCIALOAUTH_GOOGLE_SECRET_KEY": ""})
 
 
 def load_config_socialoauth(root, interactive=True):
